{% extends 'mail/_layout.html.twig' %}

{% block mail_subject %}
    {{ 'marketing.review.withdrawal_mail.subject'|trans({'%company%': company}, 'messages', locale|default('fr')) }}
{% endblock %}
{% block mail_eyebrow %}{{ company }}{% endblock %}
{% block mail_heading %}{{ 'marketing.review.withdrawal_mail.heading'|trans({}, 'messages', locale|default('fr')) }}{% endblock %}

{% block mail_body %}
    <p style="margin:0 0 24px;">
        {{ 'marketing.review.withdrawal_mail.intro'|trans({'%product%': product_label}, 'messages', locale|default('fr')) }}
    </p>

    <table role="presentation" width="100%" cellspacing="0" cellpadding="0" bgcolor="#fcf7f0" style="width:100%; margin:0 0 24px; border:1px solid #eadfce; background:#fcf7f0;">
        <tr>
            <td style="padding:18px 22px 6px; font-size:11px; letter-spacing:0.16em; text-transform:uppercase; color:#8a6a2f;">
                {{ 'marketing.review.withdrawal_mail.reason'|trans({}, 'messages', locale|default('fr')) }}
            </td>
        </tr>
        <tr>
            <td style="padding:0 22px 18px; color:#3f2f24;">
                {{ ('marketing.review.moderation.reason.' ~ reason_code)|trans({}, 'messages', locale|default('fr')) }}
                {% if reason_detail %}
                    <div style="margin-top:8px; color:#6e5848;">{{ reason_detail|e|nl2br }}</div>
                {% endif %}
            </td>
        </tr>
    </table>

    <p style="margin:0; padding-top:20px; border-top:1px solid #eadfce; font-size:14px; color:#8c7564;">
        {{ 'marketing.review.withdrawal_mail.footer'|trans({'%company%': company}, 'messages', locale|default('fr')) }}
    </p>
{% endblock %}
