{% set config = this.config %}

<div {{ attributes.defaults({
    'data-scroll-target': 'content',
    class: 'relative mx-auto flex w-full max-w-[1440px] flex-col bg-background px-4 py-16 md:px-16 md:py-24'
}) }}>
    {% if config.enablePartnerCodeFront and config.showPartnerCodeWhenShopBlocked %}
        <div class="mb-10">
            {{ component('shop:PartnerCode') }}
        </div>
    {% endif %}

    {% include 'shop/partials/blocked_notice.html.twig' with {
        config: config,
        blockedCountryCode: this.blockedCountryCode
    } only %}
</div>
