{% if not this.collectionSource or this.productCollection %}
    {% if template %}
        {% include template with {
            catalog: this,
            attributes: attributes
        } only %}
    {% else %}
        {% include '@viti_core_default/components/shop/Catalog.html.twig' %}
    {% endif %}
{% endif %}
