{% extends 'base.html.twig' %}

{% block title %}{{ 'marketing.review.policy.page_title'|trans }}{% endblock %}

{% block main %}
    <article data-review-policy-page class="relative min-h-screen overflow-hidden bg-background pt-32 pb-16 md:pt-36 md:pb-20">
        <div class="absolute inset-x-0 top-0 h-28 bg-primary md:h-32"></div>
        <div class="pointer-events-none absolute inset-x-0 top-0 h-[34rem] bg-[radial-gradient(circle_at_top,rgba(173,156,118,0.12),transparent_64%)]"></div>

        <div class="relative z-10 mx-auto max-w-[1440px] px-4 md:px-16">
            <header class="mx-auto max-w-4xl text-center">
                <span class="font-label text-[11px] font-semibold uppercase tracking-[0.22em] text-secondary">
                    {{ 'marketing.review.public.title'|trans }}
                </span>
                <h1 class="mt-4 font-display text-[34px] leading-[1.02] font-semibold [font-optical-sizing:auto] text-primary md:text-[48px]">
                    {{ 'marketing.review.policy.heading'|trans }}
                </h1>
                <p class="mx-auto mt-4 max-w-3xl text-[15px] leading-7 text-primary/72">
                    {{ 'marketing.review.policy.intro'|trans }}
                </p>
            </header>

            <div class="mx-auto mt-10 max-w-4xl border border-primary/10 bg-surface-container-low p-5 shadow-[0_20px_60px_rgba(51,38,28,0.06)] md:p-7">
                <div class="divide-y divide-primary/10 border border-primary/8 bg-white/70 px-5 md:px-8">
                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.collection.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.collection.text'|trans }}</p>
                    </section>

                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.verified.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.verified.text'|trans }}</p>
                    </section>

                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.control.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">
                            {{ (moderation_enabled
                                ? 'marketing.review.policy.control.enabled'
                                : 'marketing.review.policy.control.disabled')|trans }}
                        </p>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.control.contact'|trans }}</p>
                    </section>

                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.neutrality.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.neutrality.text'|trans }}</p>
                        <p class="mt-3 border-l-2 border-secondary bg-background px-4 py-3 text-[15px] leading-7 text-primary/72">
                            {{ 'marketing.review.policy.neutrality.example'|trans }}
                        </p>
                    </section>

                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.refusal.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.refusal.intro'|trans }}</p>
                        <ul class="mt-4 list-disc space-y-3 pl-6 text-[15px] leading-7 text-primary/72 marker:text-secondary">
                            <li>{{ 'marketing.review.policy.refusal.illegal'|trans }}</li>
                            <li>{{ 'marketing.review.policy.refusal.personal_data'|trans }}</li>
                            <li>{{ 'marketing.review.policy.refusal.off_topic'|trans }}</li>
                            <li>{{ 'marketing.review.policy.refusal.spam'|trans }}</li>
                            <li>{{ 'marketing.review.policy.refusal.fraud'|trans }}</li>
                            <li>{{ 'marketing.review.policy.refusal.incomprehensible'|trans }}</li>
                        </ul>
                        <p class="mt-4 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.refusal.notice'|trans }}</p>
                    </section>

                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.publication.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">
                            {{ 'marketing.review.policy.publication.text'|trans({
                                '%publication_days%': constant('CpCreation\\VitiCore\\Marketing\\ReviewPublicationPolicy::MAX_PUBLICATION_DELAY_DAYS'),
                                '%retention_years%': constant('CpCreation\\VitiCore\\Marketing\\ReviewPublicationPolicy::PUBLIC_RETENTION_YEARS')
                            }) }}
                        </p>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.publication.sort'|trans }}</p>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">
                            {{ 'marketing.review.policy.publication.purge'|trans({
                                '%grace_days%': constant('CpCreation\\VitiCore\\Marketing\\ReviewPublicationPolicy::UNUSED_INVITATION_GRACE_DAYS'),
                                '%retention_years%': constant('CpCreation\\VitiCore\\Marketing\\ReviewPublicationPolicy::REVIEW_DATA_RETENTION_YEARS')
                            }) }}
                        </p>
                    </section>

                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.compensation.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.compensation.text'|trans }}</p>
                    </section>

                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.changes.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.changes.text'|trans }}</p>
                    </section>

                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.reply.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.reply.text'|trans }}</p>
                    </section>

                    {% if policy_additional_content|default('')|striptags|trim is not empty %}
                        <section class="py-7">
                            <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                                {{ 'marketing.review.policy.additional.title'|trans }}
                            </h2>
                            <div class="mt-3 text-[15px] leading-7 text-primary/72 [&_a]:underline [&_a]:underline-offset-4 [&_li]:ml-5 [&_ol]:my-3 [&_p]:my-3 [&_ul]:my-3">
                                {{ policy_additional_content|raw }}
                            </div>
                        </section>
                    {% endif %}

                    <section class="py-7">
                        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                            {{ 'marketing.review.policy.certification.title'|trans }}
                        </h2>
                        <p class="mt-3 text-[15px] leading-7 text-primary/72">{{ 'marketing.review.policy.certification.text'|trans }}</p>
                    </section>
                </div>
            </div>
        </div>
    </article>
{% endblock %}
