<turbo-stream action="append" targets="#alert">
    <template>
        <twig:Notification
            message="{{ message }}"
            level="{{ level }}"
            class="pointer-events-auto w-full"
        />
    </template>
</turbo-stream>
