<meta charset="UTF-8">
<title>{{ head_title|default('site.name'|trans)|striptags }}</title>
<link rel="icon" href="{{ asset(viti_theme_asset('favicon/favicon.ico')) }}" sizes="any">
<link rel="icon" type="image/png" sizes="32x32" href="{{ asset(viti_theme_asset('favicon/favicon-32x32.png')) }}" media="(prefers-color-scheme: light)">
<link rel="icon" type="image/png" sizes="16x16" href="{{ asset(viti_theme_asset('favicon/favicon-16x16.png')) }}" media="(prefers-color-scheme: light)">
<link rel="icon" type="image/png" sizes="32x32" href="{{ asset(viti_theme_asset('favicon/favicon-dark-32x32.png')) }}" media="(prefers-color-scheme: dark)">
<link rel="icon" type="image/png" sizes="16x16" href="{{ asset(viti_theme_asset('favicon/favicon-dark-16x16.png')) }}" media="(prefers-color-scheme: dark)">
<link rel="apple-touch-icon" sizes="180x180" href="{{ asset(viti_theme_asset('favicon/apple-touch-icon.png')) }}">
<link rel="manifest" href="{{ asset(viti_theme_asset('favicon/site.webmanifest')) }}">
<link rel="preconnect" href="https://fonts.googleapis.com">
<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
<link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Libre+Bodoni:opsz,wght@6..96,400..900&family=Libre+Franklin:wght@100..900&family=Material+Symbols+Outlined:wght@100..700&display=swap">

{{ head_meta|default('')|raw }}

{{ component('seo:SiteStructuredData', {
    pageTitle: head_title|default('')|striptags|trim,
    homepageTitle: 'homepage.title'|trans({}, 'meta')
}) }}

{% set theme_entry = viti_theme().name %}

{% if app.environment == 'dev' %}
    {{ encore_entry_link_tags('app', null, 'front') }}
    {{ encore_entry_link_tags(theme_entry, null, 'front') }}
    {{ encore_entry_script_tags('app', null, 'front') }}
    {{ encore_entry_script_tags(theme_entry, null, 'front') }}
{% else %}
    {% set scriptNonce = csp_nonce('script') %}
    {% set styleNonce = csp_nonce('style') %}
    {{ encore_entry_link_tags('app', null, 'front', { nonce: styleNonce }) }}
    {{ encore_entry_link_tags(theme_entry, null, 'front', { nonce: styleNonce }) }}
    <meta name="csp-nonce" content="{{ scriptNonce }}">
    {{ encore_entry_script_tags('app', null, 'front', { nonce: scriptNonce }) }}
    {{ encore_entry_script_tags(theme_entry, null, 'front', { nonce: scriptNonce }) }}
{% endif %}

{{ head_stylesheets|default('')|raw }}
{{ head_javascripts|default('')|raw }}
{{ component('tracking:Scripts', { position: 'head' }) }}

<meta name="viewport" content="width=device-width, initial-scale=1.0">
<meta name="turbo-refresh-method" content="morph">
<meta name="turbo-cache-control" content="no-cache">
<meta name="view-transition" content="same-origin">
<meta name="x-window-id" content="{{ app.request.headers.get('X-Window-Id') }}">
<meta name="x-mer" content="{{ app.request.headers.get('x-mer') }}">
