<div
    id="alert"
    data-live-ignore
    {{ turbo_stream_listen('/notifier') }}
    class="pointer-events-none fixed inset-x-4 top-20 z-[120] flex flex-col gap-3 sm:left-auto sm:right-5 sm:w-full sm:max-w-sm"
    data-turbo-cache="false"
    data-theme-notification-success-message="{{ 'theme.notification.added_to_cart'|trans }}"
    data-theme-notification-close-label="{{ 'theme.notification.close'|trans }}">
    {% for level, messages in app.flashes() %}
        {% for message in messages %}
            <twig:Notification
                message="{{ message }}"
                level="{{ level }}"
                class="pointer-events-auto w-full"
            />
        {% endfor %}
    {% endfor %}
</div>
