<!DOCTYPE html>
<html lang="{{ app.request.locale }}">
<head>
    {% set head_title %}{% block title %}{{ 'homepage.title'|trans({}, 'meta') }}{% endblock %}{% endset %}
    {% set head_meta %}{% block meta %}{% endblock %}{% endset %}
    {% set head_stylesheets %}{% block stylesheets %}{% endblock %}{% endset %}
    {% set head_javascripts %}{% block javascripts %}{% endblock %}{% endset %}
    {{ include('partials/head.html.twig', {
        head_title: head_title,
        head_meta: head_meta,
        head_stylesheets: head_stylesheets,
        head_javascripts: head_javascripts
    }) }}
</head>
<body {% block body_attributes %}x-data="heritageLayout()" class="overflow-x-hidden bg-background font-body text-base text-primary selection:bg-secondary/20 selection:text-primary"{% endblock %} @keydown.esc.window="mobileMenuOpen = false; closeCart()">
{{ component('tracking:Scripts', { position: 'body' }) }}

{% block header %}
    <div class="relative z-50">
        {{ component('announcement:Banner') }}
        {% block header_top %}{% endblock %}
        {% include 'partials/_site_nav.html.twig' %}
    </div>
{% endblock %}

<main id="main" class="relative">
    {% block main %}{% endblock %}
</main>

{% block footer %}
    {% include 'partials/_site_footer.html.twig' %}
{% endblock %}

{% block mobile_bottom_bar %}{% endblock %}
{% include 'shop/partials/cart.html.twig' %}
{{ component('announcement:Modal') }}
{{ component('modal:SimpleModalDegressivity') }}
{{ component('modal:SimpleModalAward') }}
{{ component('modal:SimpleModalProductDetail') }}
{{ component('modal:SimpleModalProductReviews') }}
{{ component('modal:ShopInformation') }}
{{ include('partials/notifier.html.twig') }}
</body>
</html>
