{{ 'theme.mail.contact.intro'|trans({'%company%': company}) }}

{{ 'theme.mail.contact.name'|trans }} : {{ data.firstname|default('') }} {{ data.lastname|default('') }}
{{ 'theme.mail.contact.email'|trans }} : {{ data.email|default('theme.mail.not_provided'|trans) }}
{{ 'theme.mail.contact.phone'|trans }} : {{ data.phone|default('theme.mail.not_provided'|trans) }}
{{ 'theme.mail.contact.subject_label'|trans }} : {{ data.object|default('theme.mail.not_provided'|trans) }}

{{ 'theme.mail.contact.message'|trans }} :
{{ data.message|default('') }}
