{% props
    variant = 'dark',
    path = null,
    alt = null,
    width = 194,
    height = 123,
    imageClass = 'h-full w-auto object-contain'
%}

{% set defaultPath = variant == 'light' ? 'images/logo-wh.svg' : 'images/logo-bk.svg' %}
{% set logoPath = path ?: asset(viti_theme_asset(defaultPath)) %}

<div {{ attributes }}>
    <img
        src="{{ logoPath }}"
        alt="{{ alt ?: 'site.name'|trans }}"
        width="{{ width }}"
        height="{{ height }}"
        class="{{ imageClass }}"
    >
</div>
