{% extends 'mail/_layout.html.twig' %}

{% block mail_subject %}{{ 'security.mail.reset.subject'|trans({}, null, locale|default('fr')) }}{% endblock %}
{% block mail_eyebrow %}{{ 'security.mail.reset.eyebrow'|trans({}, null, locale|default('fr')) }}{% endblock %}
{% block mail_heading %}{{ 'security.mail.reset.heading'|trans({}, null, locale|default('fr')) }}{% endblock %}

{% block mail_body %}
    <p style="margin:0 0 16px;">{{ 'security.mail.reset.greeting'|trans({}, null, locale|default('fr')) }}</p>
    <p style="margin:0 0 16px;">{{ 'security.mail.reset.intro'|trans({'%company%': company }, null, locale|default('fr')) }}</p>
    <p style="margin:0 0 24px;">{{ 'security.mail.reset.instructions'|trans({}, null, locale|default('fr')) }}</p>

    <table role="presentation" cellspacing="0" cellpadding="0" style="margin:0 auto 26px;">
        <tr>
            <td class="email-button" align="center" style="background:#3f2f24;">
                <a href="{{ reset_url }}"
                   style="display:inline-block; padding:16px 28px; color:#ffffff; text-decoration:none; font-size:11px; letter-spacing:0.22em; text-transform:uppercase; font-weight:600;">
                    {{ 'security.mail.reset.cta'|trans({}, null, locale|default('fr')) }}
                </a>
            </td>
        </tr>
    </table>

    <div class="email-block" style="margin:0 0 24px; padding:18px 22px; border:1px solid #eadfce; background:#fcf7f0;">
        <div style="margin:0 0 8px; font-size:11px; letter-spacing:0.18em; text-transform:uppercase; color:#8a6a2f;">
            {{ 'security.mail.reset.fallback'|trans({}, null, locale|default('fr')) }}
        </div>
        <a href="{{ reset_url }}" style="color:#8a5a34; word-break:break-word;">{{ reset_url }}</a>
    </div>

    <p style="margin:0 0 16px;">{{ 'security.mail.reset.expiry'|trans({'%date%': expires_at|date('d/m/Y H:i') }, null, locale|default('fr')) }}</p>
    <p style="margin:0;">{{ 'security.mail.reset.ignore'|trans({}, null, locale|default('fr')) }}</p>
{% endblock %}
