{% extends 'mail/_layout.html.twig' %}

{% block mail_subject %}{{ 'theme.mail.contact.subject'|trans }}{% endblock %}
{% block mail_eyebrow %}{{ 'theme.mail.contact.eyebrow'|trans }}{% endblock %}
{% block mail_heading %}{{ 'theme.mail.contact.heading'|trans }}{% endblock %}
{% block mail_header_extra %}{{ 'theme.mail.contact.intro'|trans({'%company%': company }) }}{% endblock %}

{% block mail_body %}
    <table role="presentation" width="100%" cellspacing="0" cellpadding="0" style="width:100%; margin:0 0 24px; border-top:1px solid #eadfce; border-bottom:1px solid #eadfce;">
        <tr>
            <td class="email-line-label" style="width:160px; padding:16px 0; vertical-align:top; font-size:11px; letter-spacing:0.18em; text-transform:uppercase; color:#8a6a2f;">{{ 'theme.mail.contact.name'|trans }}</td>
            <td class="email-line-value" style="padding:16px 0; color:#3f2f24;">{{ data.firstname|default('') }} {{ data.lastname|default('') }}</td>
        </tr>
        <tr>
            <td class="email-line-label" style="width:160px; padding:16px 0; vertical-align:top; font-size:11px; letter-spacing:0.18em; text-transform:uppercase; color:#8a6a2f;">{{ 'theme.mail.contact.email'|trans }}</td>
            <td class="email-line-value" style="padding:16px 0; color:#3f2f24;">
                {% if data.email is defined and data.email %}
                    <a href="mailto:{{ data.email }}" style="color:#8a5a34; text-decoration:none;">{{ data.email }}</a>
                {% else %}
                    {{ 'theme.mail.not_provided'|trans }}
                {% endif %}
            </td>
        </tr>
        <tr>
            <td class="email-line-label" style="width:160px; padding:16px 0; vertical-align:top; font-size:11px; letter-spacing:0.18em; text-transform:uppercase; color:#8a6a2f;">{{ 'theme.mail.contact.phone'|trans }}</td>
            <td class="email-line-value" style="padding:16px 0; color:#3f2f24;">{{ data.phone|default('theme.mail.not_provided'|trans) }}</td>
        </tr>
        <tr>
            <td class="email-line-label" style="width:160px; padding:16px 0; vertical-align:top; font-size:11px; letter-spacing:0.18em; text-transform:uppercase; color:#8a6a2f;">{{ 'theme.mail.contact.subject_label'|trans }}</td>
            <td class="email-line-value" style="padding:16px 0; color:#3f2f24;">{{ data.object|default('theme.mail.not_provided'|trans) }}</td>
        </tr>
    </table>

    <div style="margin:0 0 10px; font-size:11px; letter-spacing:0.18em; text-transform:uppercase; color:#8a6a2f;">{{ 'theme.mail.contact.message'|trans }}</div>
    <div class="email-block" style="padding:20px 22px; border:1px solid #eadfce; background:#fcf7f0; color:#3f2f24;">
        {{ data.message|default('')|nl2br }}
    </div>
{% endblock %}
