import stimulusManager from "@cpcreation/viti-core/js/stimulusManager.js";
stimulusManager.load(require.context(
    "@symfony/stimulus-bridge/lazy-controller-loader!../controllers",
    true,
    /\.(j|t)sx?$/
));
import Alpine from "@alpinejs/csp";
import morph from '@alpinejs/morph'
import focus from '@alpinejs/focus'
import '@cpcreation/viti-core/js/livePatch-alpine';
import alpineManager from "@cpcreation/viti-core/js/alpineManager.js";
import registerTheme from "./theme";
import CollectionCarouselController from "../controllers/collection_carousel_controller";

Alpine.plugin(morph);
Alpine.plugin(focus);
window.Alpine = Alpine;
alpineManager.registerAll();
registerTheme(Alpine);
Alpine.start();

import {Alert} from "tailwindcss-stimulus-components";

stimulusManager.register("alert", Alert);
window.setTimeout(() => {
    stimulusManager.register("collection-carousel", CollectionCarouselController);
}, 0);
import '../css/app.css';
import '../css/components/_bouzy-vineyard-map.scss';
