{% if contact.committeeChampagneSiret or contact.committeeChampagneIdentifiant %}
    <section class="border border-primary/8 bg-white/70 p-5 md:p-7">
        <h2 class="font-display text-[26px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
            {{ 'legal_pages.agec.title'|trans }}
        </h2>
        <p class="mt-5 text-[15px] leading-7 text-primary/72">{{ 'legal_pages.agec.intro'|trans }}</p>
        <ul class="mt-4 space-y-3 text-[15px] leading-7 text-primary/72">
            {% if contact.committeeChampagneSiret %}
                <li>{{ 'legal_pages.agec.committee_champagne_siret'|trans({ '%value%': contact.committeeChampagneSiret }) }}</li>
            {% endif %}
            {% if contact.committeeChampagneIdentifiant %}
                <li>{{ 'legal_pages.agec.committee_champagne_identifier'|trans({ '%value%': contact.committeeChampagneIdentifiant }) }}</li>
            {% endif %}
        </ul>
    </section>
{% endif %}
